.. This file is a part of the AnyBlok project
..
..    Copyright (C) 2015 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
..
.. This Source Code Form is subject to the terms of the Mozilla Public License,
.. v. 2.0. If a copy of the MPL was not distributed with this file,You can
.. obtain one at http://mozilla.org/MPL/2.0/.

API doc
~~~~~~~

**exceptions**

.. automodule:: anyblok.bloks.io.exceptions

.. autoexception:: IOException
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoexception:: IOMappingCheckException
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoexception:: IOMappingSetException
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoexception:: ImporterException
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoexception:: ExporterException
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoexception:: FormaterException
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

**mapping**

.. automodule:: anyblok.bloks.io.mapping

.. autoclass:: Mapping
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

**mixin**

.. automodule:: anyblok.bloks.io.mixin

.. autoclass:: IOMixin
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

**importer**

.. automodule:: anyblok.bloks.io.importer

.. autoclass:: Importer
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

**exporter**

.. automodule:: anyblok.bloks.io.exporter

.. autoclass:: Exporter
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

**formater**

.. automodule:: anyblok.bloks.io.formater

.. autoclass:: Formater
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: Float
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: Decimal
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: Json
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: Interval
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: Integer
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: SmallInteger
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: BigInteger
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: Boolean
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: Time
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: Date
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: DateTime
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: Many2One
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: One2One
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: Many2Many
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. autoclass:: One2Many
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:
